==> ejc-technologymanage-api-3.0.0-20221115.020044-16-sources.jar: com/ejianc/business/constructor/vo/JsglViewVO.java <==
package com.ejianc.business.constructor.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 技术管理视图
 * 
 * @author generator
 * 
 */
public class JsglViewVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String famc; // 方案名称
    private Long falxId; // 方案类型id
    private String falxName; // 方案类型
    private Long gcxmmcId; // 工程项目名称id
    private String gcxmmcName; // 工程项目名称
    private Long sgdwId; // 施工单位id
    private String sgdwName; // 施工单位
    private Long gcjdId; // 工程阶段id
    private String gcjdName; // 工程阶段
    private Long gclbId; // 工程类别id
    private String gclbName; // 工程类别
    private Long jglxId; // 结构类型id
    private String jglxName; // 结构类型
    private Long ssxjzId; // 所属巡检组id
    private String ssxjzName; // 所属巡检组
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date htkgrq; // 合同开工日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date htjgrq; // 合同竣工日期
    private Integer jlsq; // 监理审批(0:是 1：否)
    private String tags; // 分类标签

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getFamc() {
        return famc;
    }

    public void setFamc(String famc) {
        this.famc = famc;
    }

    @ReferSerialTransfer(referCode = "fazd")
    public Long getFalxId() {
        return falxId;
    }
    @ReferDeserialTransfer
    public void setFalxId(Long falxId) {
        this.falxId = falxId;
    }
    public String getFalxName() {
        return falxName;
    }

    public void setFalxName(String falxName) {
        this.falxName = falxName;
    }
    @ReferSerialTransfer(referCode = "project-set")

    public Long getGcxmmcId() {
        return gcxmmcId;
    }
    @ReferDeserialTransfer
    public void setGcxmmcId(Long gcxmmcId) {
        this.gcxmmcId = gcxmmcId;
    }
    public String getGcxmmcName() {
        return gcxmmcName;
    }

    public void setGcxmmcName(String gcxmmcName) {
        this.gcxmmcName = gcxmmcName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public Long getGcjdId() {
        return gcjdId;
    }

    public void setGcjdId(Long gcjdId) {
        this.gcjdId = gcjdId;
    }
    public String getGcjdName() {
        return gcjdName;
    }

    public void setGcjdName(String gcjdName) {
        this.gcjdName = gcjdName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getGclbId() {
        return gclbId;
    }
    @ReferDeserialTransfer
    public void setGclbId(Long gclbId) {
        this.gclbId = gclbId;
    }
    public String getGclbName() {
        return gclbName;
    }

    public void setGclbName(String gclbName) {
        this.gclbName = gclbName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getJglxId() {
        return jglxId;
    }
    @ReferDeserialTransfer
    public void setJglxId(Long jglxId) {
        this.jglxId = jglxId;
    }
    public String getJglxName() {
        return jglxName;
    }

    public void setJglxName(String jglxName) {
        this.jglxName = jglxName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSsxjzId() {
        return ssxjzId;
    }
    @ReferDeserialTransfer
    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public Date getHtkgrq() {
        return htkgrq;
    }

    public void setHtkgrq(Date htkgrq) {
        this.htkgrq = htkgrq;
    }
    public Date getHtjgrq() {
        return htjgrq;
    }

    public void setHtjgrq(Date htjgrq) {
        this.htjgrq = htjgrq;
    }
    public Integer getJlsq() {
        return jlsq;
    }

    public void setJlsq(Integer jlsq) {
        this.jlsq = jlsq;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }
}

==> ejc-technologymanage-api-3.0.0-20230620.065051-33-sources.jar: com/ejianc/business/constructor/vo/JsglViewVO.java <==
package com.ejianc.business.constructor.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 技术管理视图
 * 
 * @author generator
 * 
 */
public class JsglViewVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String famc; // 方案名称
    private Long falxId; // 方案类型id
    private String falxName; // 方案类型
    private Long gcxmmcId; // 工程项目名称id
    private String gcxmmcName; // 工程项目名称
    private Long sgdwId; // 施工单位id
    private String sgdwName; // 施工单位
    private Long gcjdId; // 工程阶段id
    private String gcjdName; // 工程阶段
    private Long gclbId; // 工程类别id
    private String gclbName; // 工程类别
    private Long jglxId; // 结构类型id
    private String jglxName; // 结构类型
    private Long ssxjzId; // 所属巡检组id
    private String ssxjzName; // 所属巡检组
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date htkgrq; // 合同开工日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date htjgrq; // 合同竣工日期
    private Integer jlsq; // 监理审批(0:是 1：否)
    private String tags; // 分类标签
    private Integer gd; // 是否完成归档(0:是 1：否)

    public Integer getGd() {
        return gd;
    }

    public void setGd(Integer gd) {
        this.gd = gd;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getFamc() {
        return famc;
    }

    public void setFamc(String famc) {
        this.famc = famc;
    }

    @ReferSerialTransfer(referCode = "fazd")
    public Long getFalxId() {
        return falxId;
    }
    @ReferDeserialTransfer
    public void setFalxId(Long falxId) {
        this.falxId = falxId;
    }
    public String getFalxName() {
        return falxName;
    }

    public void setFalxName(String falxName) {
        this.falxName = falxName;
    }
    @ReferSerialTransfer(referCode = "project-set")

    public Long getGcxmmcId() {
        return gcxmmcId;
    }
    @ReferDeserialTransfer
    public void setGcxmmcId(Long gcxmmcId) {
        this.gcxmmcId = gcxmmcId;
    }
    public String getGcxmmcName() {
        return gcxmmcName;
    }

    public void setGcxmmcName(String gcxmmcName) {
        this.gcxmmcName = gcxmmcName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public Long getGcjdId() {
        return gcjdId;
    }

    public void setGcjdId(Long gcjdId) {
        this.gcjdId = gcjdId;
    }
    public String getGcjdName() {
        return gcjdName;
    }

    public void setGcjdName(String gcjdName) {
        this.gcjdName = gcjdName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getGclbId() {
        return gclbId;
    }
    @ReferDeserialTransfer
    public void setGclbId(Long gclbId) {
        this.gclbId = gclbId;
    }
    public String getGclbName() {
        return gclbName;
    }

    public void setGclbName(String gclbName) {
        this.gclbName = gclbName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getJglxId() {
        return jglxId;
    }
    @ReferDeserialTransfer
    public void setJglxId(Long jglxId) {
        this.jglxId = jglxId;
    }
    public String getJglxName() {
        return jglxName;
    }

    public void setJglxName(String jglxName) {
        this.jglxName = jglxName;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSsxjzId() {
        return ssxjzId;
    }
    @ReferDeserialTransfer
    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public Date getHtkgrq() {
        return htkgrq;
    }

    public void setHtkgrq(Date htkgrq) {
        this.htkgrq = htkgrq;
    }
    public Date getHtjgrq() {
        return htjgrq;
    }

    public void setHtjgrq(Date htjgrq) {
        this.htjgrq = htjgrq;
    }
    public Integer getJlsq() {
        return jlsq;
    }

    public void setJlsq(Integer jlsq) {
        this.jlsq = jlsq;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }
}
